@@ -2,6 +2,20 @@
 ###
 ### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 
 ##*## Generics that should be implemented for any varFunc class
 
@@ -258,7 +272,7 @@ varIdent <-
       value <- log(value)               # unconstrained form
     } else grpNames <- NULL
     attr(value, "groupNames") <- grpNames
-    if (!is.null(attr(value, "fixed"))) {
+    if (!is.null(fixed)) {
        fix <- attr(value, "fixed") <- log(unlist(fixed))
       if (is.null(fixNames <- names(fix))) {
 	stop("Fixed parameters must have names in varIdent")
