@@ -1,10 +1,9 @@
-/* $Id: nlOptimizer.h,v 1.1 2000/03/17 22:21:24 saikat Exp $
-
+/*
    header file for the nlme package
 
    Copyright 1999 Saikat DebRoy <saikat@stat.wisc.edu>
 
-   This file is part of the nlme library for R and related languages
+   This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
    License, version 2, or at your option, any later version,
    incorporated herein by reference.
@@ -15,11 +14,10 @@
    PURPOSE.  See the GNU General Public License for more
    details.
 
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA
- 
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
+
 */
 
 #ifndef NLME_NLOPTIMIZER_H
